"""
    Delphix API Gateway

    Delphix API Gateway API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.environment import Environment
from delphix.api.gateway.model.errors import Errors
globals()['Environment'] = Environment
globals()['Errors'] = Errors
from delphix.api.gateway.model.list_environments_response import ListEnvironmentsResponse


class TestListEnvironmentsResponse(unittest.TestCase):
    """ListEnvironmentsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListEnvironmentsResponse(self):
        """Test ListEnvironmentsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListEnvironmentsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
