"""
    Delphix API Gateway

    Delphix API Gateway API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.api_keys_api import ApiKeysApi  # noqa: E501


class TestApiKeysApi(unittest.TestCase):
    """ApiKeysApi unit test stubs"""

    def setUp(self):
        self.api = ApiKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_api_key(self):
        """Test case for create_api_key

        Create a new API key. If no API key exists yet, or all tokens for existing API keys have been lost, the application container container can be TEMPORARILY started with the API_KEY_CREATE environment variable set to string \"true\" and the application will create a new API key when starting and print the corresponding token to the logs. API keys created using the environment variable mechanism should only be used to boostrap the creation of other - more secure - API keys and be discarded.   # noqa: E501
        """
        pass

    def test_delete_api_key(self):
        """Test case for delete_api_key

        Delete an API key  # noqa: E501
        """
        pass

    def test_get_api_key(self):
        """Test case for get_api_key

        Get an API key by id  # noqa: E501
        """
        pass

    def test_list_api_keys(self):
        """Test case for list_api_keys

        Returns a list of API keys.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
